declare type SqlValue = string | number | null | Uint8Array;
interface QueryExecResult {
    columns: Array<string>;
    values: Array<Array<SqlValue>>;
}
declare type BindParams = Array<SqlValue> | Record<string, SqlValue> | null;
interface SqlLite {
    exec: (query: string, params?: BindParams) => Array<QueryExecResult>;
}
declare type SqlDataType = 'INTEGER' | 'INT' | 'TEXT';
interface Schema {
    [tableName: string]: {
        fields: Record<string, SqlDataType>;
        values?: Array<Record<string, string | number>>;
    };
}

declare const createSQL: (path: string, schema: Schema) => Promise<SqlLite | undefined>;

declare function useQuery(query: string, depths?: Array<string | number | boolean | undefined | null>): {
    result: QueryExecResult[] | undefined;
    writeQueryFn: (query: string) => void;
};

export { createSQL as default, useQuery };
